## Changelog 🔄
All notable changes to `isaacus-sagemaker` will be documented here. This project adheres to [Keep a Changelog](https://keepachangelog.com/en/1.1.0/) and [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.3] - 2025-10-27
### Changed
- Updated README to link to Isaacus' AWS Marketplace listings.

## [0.1.2] - 2025-10-26
### Added
- Added PyPI classifiers.

### Fixed
- Updated CHANGELOG.
- Updated URLs in `pyproject.toml` to point to the correct repository.

## [0.1.1] - 2025-10-26
### Added
- Added shields to README.

### Fixed
- Fixed typo in README.

## [0.1.0] - 2025-10-26
### Added
- Initial release of `isaacus-sagemaker`, providing synchronous and asynchronous HTTP clients for interacting with Isaacus models deployed on AWS SageMaker via the SageMaker Runtime InvokeEndpoint API.

[0.1.3]: https://github.com/isaacus-dev/isaacus-sagemaker-python/compare/v0.1.2...v0.1.3
[0.1.2]: https://github.com/isaacus-dev/isaacus-sagemaker-python/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/isaacus-dev/isaacus-sagemaker-python/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/isaacus-dev/isaacus-sagemaker-python/releases/tag/v0.1.0